@@ -144,6 +144,7 @@ namespace Oxygen
 
             // buttons
             case AbilityButtonMenu:
+            case AbilityButtonApplicationMenu:
             case AbilityButtonHelp:
             case AbilityButtonMinimize:
             case AbilityButtonMaximize:
@@ -164,6 +165,7 @@ namespace Oxygen
             return true;
 
             case AbilityUsesAlphaChannel:
+            case AbilityAnnounceAlphaChannel:
             return true;
 
             // tabs
