@@ -41,6 +41,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtGui/QVector2D>
 #include <Plasma/FrameSvg>
 #include <Plasma/PushButton>
+#include <Plasma/Theme>
 #include <Plasma/WindowEffects>
 
 namespace KWin
@@ -1418,7 +1419,11 @@ DesktopButtonsView::DesktopButtonsView(QWidget* parent)
     scene->addItem(form);
 
     m_frame = new Plasma::FrameSvg(this);
-    m_frame->setImagePath("dialogs/background");
+    if (Plasma::Theme::defaultTheme()->currentThemeHasImage("translucent/dialogs/background")) {
+        m_frame->setImagePath("translucent/dialogs/background");
+    } else {
+        m_frame->setImagePath("dialogs/background");
+    }
     m_frame->setCacheAllRenderedFrames(true);
     m_frame->setEnabledBorders(Plasma::FrameSvg::AllBorders);
     qreal left, top, right, bottom;
@@ -1427,7 +1432,6 @@ DesktopButtonsView::DesktopButtonsView(QWidget* parent)
     qreal height = form->size().height() + top + bottom;
     m_frame->resizeFrame(QSizeF(width, height));
     Plasma::WindowEffects::enableBlurBehind(winId(), true, m_frame->mask());
-    Plasma::WindowEffects::overrideShadow(winId(), true);
     form->setPos(left, top);
     scene->setSceneRect(QRectF(QPointF(0, 0), QSizeF(width, height)));
     setScene(scene);
