@@ -20,6 +20,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "login.h"
 
+// KConfigSkeleton
+#include "loginconfig.h"
+
 #include <kdebug.h>
 
 #include <KDE/KConfigGroup>
@@ -67,13 +70,13 @@ void LoginEffect::paintWindow(EffectWindow* w, int mask, QRegion region, WindowP
     if (w == login_window) {
         if (m_fadeToBlack) {
             if (progress < 0.5)
-                data.brightness *= (1.0 - progress * 2);
+                data.multiplyBrightness((1.0 - progress * 2));
             if (progress >= 0.5) {
-                data.opacity *= (1.0 - (progress - 0.5) * 2);
-                data.brightness = 0;
+                data.multiplyOpacity((1.0 - (progress - 0.5) * 2));
+                data.setBrightness(0);
             }
         } else if (progress < 1.0) {
-            data.opacity *= (1.0 - progress);
+            data.multiplyOpacity((1.0 - progress));
         }
     }
     
@@ -89,8 +92,8 @@ void LoginEffect::postPaintScreen()
 
 void LoginEffect::reconfigure(ReconfigureFlags)
 {
-    KConfigGroup conf = effects->effectConfig("Login");
-    m_fadeToBlack = (conf.readEntry("FadeToBlack", false));
+    LoginConfig::self()->readConfig();
+    m_fadeToBlack = LoginConfig::fadeToBlack();
 }
 
 void LoginEffect::slotWindowClosed(EffectWindow* w)
