@@ -30,6 +30,8 @@ class ResizeEffect
     : public Effect
 {
     Q_OBJECT
+    Q_PROPERTY(bool textureScale READ isTextureScale)
+    Q_PROPERTY(bool outline READ isOutline)
 public:
     ResizeEffect();
     ~ResizeEffect();
@@ -42,6 +44,13 @@ public:
     virtual void paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data);
     virtual void reconfigure(ReconfigureFlags);
 
+    bool isTextureScale() const {
+        return m_features & TextureScale;
+    }
+    bool isOutline() const {
+        return m_features & Outline;
+    }
+
 public Q_SLOTS:
     void slotWindowStartUserMovedResized(KWin::EffectWindow *w);
     void slotWindowStepUserMovedResized(KWin::EffectWindow *w, const QRect &geometry);
