@@ -42,8 +42,6 @@ public:
     explicit TranslucencyEffectConfig(QWidget* parent = 0, const QVariantList& args = QVariantList());
 
     virtual void save();
-    virtual void load();
-    virtual void defaults();
 
 private:
     TranslucencyEffectConfigForm* m_ui;
