@@ -24,6 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // need to call GLTexturePrivate::initStatic()
 #include "kwingltexture_p.h"
 
+#include "kwinglcolorcorrection.h"
 #include "kwinglobals.h"
 #include "kwineffects.h"
 #include "kwinglplatform.h"
@@ -61,7 +62,6 @@ static int eglVersion;
 static QStringList glExtensions;
 static QStringList glxExtensions;
 static QStringList eglExtension;
-static bool legacyGl;
 
 int glTextureUnitsCount;
 
@@ -84,7 +84,7 @@ void initGLX()
 
 void initEGL()
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_EGL
     EGLDisplay dpy = eglGetCurrentDisplay();
     int major, minor;
     eglInitialize(dpy, &major, &minor);
@@ -95,25 +95,21 @@ void initEGL()
 #endif
 }
 
-void initGL()
+void initGL(OpenGLPlatformInterface platformInterface)
 {
     // Get OpenGL version
     QString glversionstring = QString((const char*)glGetString(GL_VERSION));
     QStringList glversioninfo = glversionstring.left(glversionstring.indexOf(' ')).split('.');
     while (glversioninfo.count() < 3)
         glversioninfo << "0";
-#ifdef KWIN_HAVE_OPENGLES
-    legacyGl = false;
-#else
-    KConfigGroup config(KGlobal::config(), "Compositing");
-    legacyGl = config.readEntry<bool>("GLLegacy", false);
+#ifndef KWIN_HAVE_OPENGLES
     glVersion = MAKE_GL_VERSION(glversioninfo[0].toInt(), glversioninfo[1].toInt(), glversioninfo[2].toInt());
 #endif
     // Get list of supported OpenGL extensions
     glExtensions = QString((const char*)glGetString(GL_EXTENSIONS)).split(' ');
 
     // handle OpenGL extensions functions
-    glResolveFunctions();
+    glResolveFunctions(platformInterface);
 
     GLTexturePrivate::initStatic();
     GLRenderTarget::initStatic();
@@ -190,16 +186,22 @@ int nearestPowerOfTwo(int x)
 
 void pushMatrix()
 {
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
+    if (ShaderManager::instance()->isValid()) {
+        return;
+    }
     glPushMatrix();
 #endif
 }
 
 void pushMatrix(const QMatrix4x4 &matrix)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(matrix)
 #else
+    if (ShaderManager::instance()->isValid()) {
+        return;
+    }
     glPushMatrix();
     multiplyMatrix(matrix);
 #endif
@@ -207,9 +209,12 @@ void pushMatrix(const QMatrix4x4 &matrix)
 
 void multiplyMatrix(const QMatrix4x4 &matrix)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(matrix)
 #else
+    if (ShaderManager::instance()->isValid()) {
+        return;
+    }
     GLfloat m[16];
     const qreal *data = matrix.constData();
     for (int i = 0; i < 4; ++i) {
@@ -223,7 +228,7 @@ void multiplyMatrix(const QMatrix4x4 &matrix)
 
 void loadMatrix(const QMatrix4x4 &matrix)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(matrix)
 #else
     if (ShaderManager::instance()->isValid()) {
@@ -242,7 +247,10 @@ void loadMatrix(const QMatrix4x4 &matrix)
 
 void popMatrix()
 {
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
+    if (ShaderManager::instance()->isValid()) {
+        return;
+    }
     glPopMatrix();
 #endif
 }
@@ -251,6 +259,8 @@ void popMatrix()
 // GLShader
 //****************************************
 
+bool GLShader::sColorCorrect = false;
+
 GLShader::GLShader()
     : mProgram(0)
     , mValid(false)
@@ -292,10 +302,8 @@ bool GLShader::loadFromFiles(const QString &vertexFile, const QString &fragmentF
     return load(vertexSource, fragmentSource);
 }
 
-bool GLShader::compile(GLuint program, GLenum shaderType, const QByteArray &source) const
+const QByteArray GLShader::prepareSource(GLenum shaderType, const QByteArray &source) const
 {
-    GLuint shader = glCreateShader(shaderType);
-
     // Prepare the source code
     QByteArray ba;
 #ifdef KWIN_HAVE_OPENGLES
@@ -306,7 +314,19 @@ bool GLShader::compile(GLuint program, GLenum shaderType, const QByteArray &sour
     }
     ba.append(source);
 
-    const char* src = ba.constData();
+    // Inject color correction code for fragment shaders, if possible
+    if (shaderType == GL_FRAGMENT_SHADER && sColorCorrect)
+        ba = ColorCorrection::prepareFragmentShader(ba);
+
+    return ba;
+}
+
+bool GLShader::compile(GLuint program, GLenum shaderType, const QByteArray &source) const
+{
+    GLuint shader = glCreateShader(shaderType);
+
+    QByteArray preparedSource = prepareSource(shaderType, source);
+    const char* src = preparedSource.constData();
     glShaderSource(shader, 1, &src, NULL);
 
     // Compile the shader
@@ -423,8 +443,6 @@ void GLShader::resolveLocations()
 
     mFloatLocation[Saturation]    = uniformLocation("saturation");
 
-    mIntLocation[AlphaToOne] = uniformLocation("u_forceAlpha");
-
     mLocationsResolved = true;
 }
 
@@ -615,6 +633,16 @@ ShaderManager *ShaderManager::instance()
     return s_shaderManager;
 }
 
+void ShaderManager::disable()
+{
+    // for safety do a Cleanup first
+    ShaderManager::cleanup();
+    // create a new ShaderManager and set it to inited without calling init
+    // that will ensure that the ShaderManager is not valid
+    s_shaderManager = new ShaderManager();
+    s_shaderManager->m_inited = true;
+}
+
 void ShaderManager::cleanup()
 {
     delete s_shaderManager;
@@ -785,10 +813,6 @@ GLShader *ShaderManager::loadShaderFromCode(const QByteArray &vertexSource, cons
 
 void ShaderManager::initShaders()
 {
-    if (legacyGl) {
-        kDebug(1212) << "OpenGL Shaders disabled by config option";
-        return;
-    }
     m_orthoShader = new GLShader(":/resources/scene-vertex.glsl", ":/resources/scene-fragment.glsl");
     if (m_orthoShader->isValid()) {
         pushShader(SimpleShader, true);
@@ -882,7 +906,6 @@ void ShaderManager::resetShader(ShaderType type)
     shader->setUniform(GLShader::ModulationConstant, QVector4D(1.0, 1.0, 1.0, 1.0));
 
     shader->setUniform(GLShader::Saturation, 1.0f);
-    shader->setUniform(GLShader::AlphaToOne, 0);
 }
 
 /***  GLRenderTarget  ***/
@@ -1119,8 +1142,7 @@ class GLVertexBufferPrivate
 {
 public:
     GLVertexBufferPrivate(GLVertexBuffer::UsageHint usageHint)
-        : hint(usageHint)
-        , numberVertices(0)
+        : vertexCount(0)
         , dimension(2)
         , useColor(false)
         , useTexCoords(true)
@@ -1128,15 +1150,29 @@ public:
         if (GLVertexBufferPrivate::supported) {
             glGenBuffers(2, buffers);
         }
+
+        switch(usageHint) {
+        case GLVertexBuffer::Dynamic:
+            usage = GL_DYNAMIC_DRAW;
+            break;
+        case GLVertexBuffer::Static:
+            usage = GL_STATIC_DRAW;
+            break;
+        default:
+            usage = GL_STREAM_DRAW;
+            break;
+        }
     }
+
     ~GLVertexBufferPrivate() {
         if (GLVertexBufferPrivate::supported) {
             glDeleteBuffers(2, buffers);
         }
     }
-    GLVertexBuffer::UsageHint hint;
+
     GLuint buffers[2];
-    int numberVertices;
+    GLenum usage;
+    int vertexCount;
     int dimension;
     static bool supported;
     static GLVertexBuffer *streamingBuffer;
@@ -1158,7 +1194,7 @@ GLVertexBuffer *GLVertexBufferPrivate::streamingBuffer = NULL;
 
 void GLVertexBufferPrivate::legacyPainting(QRegion region, GLenum primitiveMode, bool hardwareClipping)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(region)
     Q_UNUSED(primitiveMode)
     Q_UNUSED(hardwareClipping)
@@ -1176,11 +1212,11 @@ void GLVertexBufferPrivate::legacyPainting(QRegion region, GLenum primitiveMode,
     }
 
     if (!hardwareClipping) {
-        glDrawArrays(primitiveMode, 0, numberVertices);
+        glDrawArrays(primitiveMode, 0, vertexCount);
     } else {
         foreach (const QRect& r, region.rects()) {
             glScissor(r.x(), displayHeight() - r.y() - r.height(), r.width(), r.height());
-            glDrawArrays(primitiveMode, 0, numberVertices);
+            glDrawArrays(primitiveMode, 0, vertexCount);
         }
     }
 
@@ -1215,11 +1251,11 @@ void GLVertexBufferPrivate::corePainting(const QRegion& region, GLenum primitive
     }
 
     if (!hardwareClipping) {
-        glDrawArrays(primitiveMode, 0, numberVertices);
+        glDrawArrays(primitiveMode, 0, vertexCount);
     } else {
         foreach (const QRect& r, region.rects()) {
             glScissor(r.x(), displayHeight() - r.y() - r.height(), r.width(), r.height());
-            glDrawArrays(primitiveMode, 0, numberVertices);
+            glDrawArrays(primitiveMode, 0, vertexCount);
         }
     }
 
@@ -1233,7 +1269,7 @@ void GLVertexBufferPrivate::corePainting(const QRegion& region, GLenum primitive
 
 void GLVertexBufferPrivate::fallbackPainting(const QRegion& region, GLenum primitiveMode, bool hardwareClipping)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(region)
     Q_UNUSED(primitiveMode)
     Q_UNUSED(hardwareClipping)
@@ -1252,11 +1288,11 @@ void GLVertexBufferPrivate::fallbackPainting(const QRegion& region, GLenum primi
 
     // Clip using scissoring
     if (!hardwareClipping) {
-        glDrawArrays(primitiveMode, 0, numberVertices);
+        glDrawArrays(primitiveMode, 0, vertexCount);
     } else {
         foreach (const QRect& r, region.rects()) {
             glScissor(r.x(), displayHeight() - r.y() - r.height(), r.width(), r.height());
-            glDrawArrays(primitiveMode, 0, numberVertices);
+            glDrawArrays(primitiveMode, 0, vertexCount);
         }
     }
 
@@ -1280,49 +1316,35 @@ GLVertexBuffer::~GLVertexBuffer()
     delete d;
 }
 
-void GLVertexBuffer::setData(int numberVertices, int dim, const float* vertices, const float* texcoords)
+void GLVertexBuffer::setData(int vertexCount, int dim, const float* vertices, const float* texcoords)
 {
-    d->numberVertices = numberVertices;
+    d->vertexCount = vertexCount;
     d->dimension = dim;
     d->useTexCoords = (texcoords != NULL);
+
     if (!GLVertexBufferPrivate::supported) {
         // legacy data
         d->legacyVertices.clear();
-        d->legacyVertices.reserve(numberVertices * dim);
-        for (int i = 0; i < numberVertices * dim; ++i) {
+        d->legacyVertices.reserve(vertexCount * dim);
+        for (int i = 0; i < vertexCount * dim; ++i) {
             d->legacyVertices << vertices[i];
         }
         d->legacyTexCoords.clear();
         if (d->useTexCoords) {
-            d->legacyTexCoords.reserve(numberVertices * 2);
-            for (int i = 0; i < numberVertices * 2; ++i) {
+            d->legacyTexCoords.reserve(vertexCount * 2);
+            for (int i = 0; i < vertexCount * 2; ++i) {
                 d->legacyTexCoords << texcoords[i];
             }
         }
         return;
     }
-    GLenum hint;
-    switch(d->hint) {
-    case Dynamic:
-        hint = GL_DYNAMIC_DRAW;
-        break;
-    case Static:
-        hint = GL_STATIC_DRAW;
-        break;
-    case Stream:
-        hint = GL_STREAM_DRAW;
-        break;
-    default:
-        // just to make the compiler happy
-        hint = GL_STREAM_DRAW;
-        break;
-    }
+
     glBindBuffer(GL_ARRAY_BUFFER, d->buffers[ 0 ]);
-    glBufferData(GL_ARRAY_BUFFER, sizeof(GLfloat)*numberVertices * d->dimension, vertices, hint);
+    glBufferData(GL_ARRAY_BUFFER, sizeof(GLfloat)*vertexCount * d->dimension, vertices, d->usage);
 
     if (d->useTexCoords) {
         glBindBuffer(GL_ARRAY_BUFFER, d->buffers[ 1 ]);
-        glBufferData(GL_ARRAY_BUFFER, sizeof(GLfloat)*numberVertices * 2, texcoords, hint);
+        glBufferData(GL_ARRAY_BUFFER, sizeof(GLfloat)*vertexCount * 2, texcoords, d->usage);
     }
 
     glBindBuffer(GL_ARRAY_BUFFER, 0);
@@ -1369,7 +1391,7 @@ void GLVertexBuffer::reset()
 {
     d->useColor       = false;
     d->color          = QColor(0, 0, 0, 255);
-    d->numberVertices = 0;
+    d->vertexCount    = 0;
     d->dimension      = 2;
     d->useTexCoords   = true;
 }
