@@ -402,14 +402,6 @@ static const char description[] = I18N_NOOP("KDE window manager");
 extern "C"
 KDE_EXPORT int kdemain(int argc, char * argv[])
 {
-    bool restored = false;
-    for (int arg = 1; arg < argc; arg++) {
-        if (!qstrcmp(argv[arg], "-session")) {
-            restored = true;
-            break;
-        }
-    }
-
 #ifdef M_TRIM_THRESHOLD
     // Prevent fragmentation of the heap by malloc (glibc).
     //
