@@ -30,7 +30,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "placement.h"
 #include "utils.h"
-#include "tilinglayoutfactory.h"
 
 namespace KWin
 {
@@ -72,15 +71,6 @@ class Options : public QObject, public KDecorationOptions
        shade hover interval
      */
     Q_PROPERTY(int shadeHoverInterval READ shadeHoverInterval WRITE setShadeHoverInterval NOTIFY shadeHoverIntervalChanged)
-    /**
-     * Whether tiling is enabled or not
-     */
-    Q_PROPERTY(bool tiling READ isTilingOn WRITE setTilingOn WRITE setTiling NOTIFY tilingChanged)
-    Q_PROPERTY(int tilingLayout READ tilingLayout WRITE setTilingLayout NOTIFY tilingLayoutChanged)
-    /**
-     * Tiling window raise policy.
-     */
-    Q_PROPERTY(int tilingRaisePolicy READ tilingRaisePolicy WRITE setTilingRaisePolicy NOTIFY tilingRaisePolicyChanged)
     /**
      * whether to see Xinerama screens separately for focus (in Alt+Tab, when activating next client)
      **/
@@ -140,6 +130,10 @@ class Options : public QObject, public KDecorationOptions
     */
     Q_PROPERTY(bool showGeometryTip READ showGeometryTip WRITE setShowGeometryTip NOTIFY showGeometryTipChanged)
     /**
+    * whether the visible name should be condensed
+    */
+    Q_PROPERTY(bool condensedTitle READ condensedTitle WRITE setCondensedTitle NOTIFY condensedTitleChanged)
+    /**
     * Whether electric borders are enabled. With electric borders
     * you can change desktop by moving the mouse pointer towards the edge
     * of the screen
@@ -165,6 +159,10 @@ class Options : public QObject, public KDecorationOptions
     * Whether a window is tiled to half screen when reaching left or right screen edge while been moved
     */
     Q_PROPERTY(bool electricBorderTiling READ electricBorderTiling WRITE setElectricBorderTiling NOTIFY electricBorderTilingChanged)
+    /**
+    * Whether a window is tiled to half screen when reaching left or right screen edge while been moved
+    */
+    Q_PROPERTY(float electricBorderCornerRatio READ electricBorderCornerRatio WRITE setElectricBorderCornerRatio NOTIFY electricBorderCornerRatioChanged)
     Q_PROPERTY(bool borderlessMaximizedWindows READ borderlessMaximizedWindows WRITE setBorderlessMaximizedWindows NOTIFY borderlessMaximizedWindowsChanged)
     /**
      * timeout before non-responding application will be killed after attempt to close
@@ -189,6 +187,7 @@ class Options : public QObject, public KDecorationOptions
      **/
     Q_PROPERTY(int glSmoothScale READ glSmoothScale WRITE setGlSmoothScale NOTIFY glSmoothScaleChanged)
     Q_PROPERTY(bool glVSync READ isGlVSync WRITE setGlVSync NOTIFY glVSyncChanged)
+    Q_PROPERTY(bool colorCorrected READ isColorCorrected WRITE setColorCorrected NOTIFY colorCorrectedChanged)
     Q_PROPERTY(bool xrenderSmoothScale READ isXrenderSmoothScale WRITE setXrenderSmoothScale NOTIFY xrenderSmoothScaleChanged)
     Q_PROPERTY(uint maxFpsInterval READ maxFpsInterval WRITE setMaxFpsInterval NOTIFY maxFpsIntervalChanged)
     Q_PROPERTY(uint refreshRate READ refreshRate WRITE setRefreshRate NOTIFY refreshRateChanged)
@@ -201,6 +200,10 @@ class Options : public QObject, public KDecorationOptions
      * If @c false @link glStrictBinding is set from a config value and not updated during scene initialization.
      **/
     Q_PROPERTY(bool glStrictBindingFollowsDriver READ isGlStrictBindingFollowsDriver WRITE setGlStrictBindingFollowsDriver NOTIFY glStrictBindingFollowsDriverChanged)
+    /**
+     * Whether legacy OpenGL should be used or OpenGL (ES) 2
+     **/
+    Q_PROPERTY(bool glLegacy READ isGlLegacy WRITE setGlLegacy NOTIFY glLegacyChanged)
 public:
 
     Options(QObject *parent = NULL);
@@ -290,30 +293,6 @@ public:
         return m_shadeHoverInterval;
     }
 
-    /**
-     * Whether tiling is enabled or not
-     */
-    bool isTilingOn() const {
-        return m_tilingOn;
-    }
-    void setTilingOn(bool enabled) {
-        m_tilingOn = enabled;
-    }
-
-    /**
-     * Tiling Layout
-     */
-    TilingLayoutFactory::Layouts tilingLayout() const {
-        return m_tilingLayout;
-    }
-
-    /**
-     * Tiling window raise policy.
-     */
-    int tilingRaisePolicy() const {
-        return m_tilingRaisePolicy;
-    }
-
     // whether to see Xinerama screens separately for focus (in Alt+Tab, when activating next client)
     bool isSeparateScreenFocus() const {
         return m_separateScreenFocus;
@@ -470,6 +449,11 @@ public:
     */
     bool showGeometryTip() const;
 
+    /**
+     * returns whether the user prefers his caption clean
+     */
+    bool condensedTitle() const;
+
     enum { ElectricDisabled = 0, ElectricMoveOnly = 1, ElectricAlways = 2 };
     /**
     * @returns The action assigned to the specified electric border
@@ -510,6 +494,12 @@ public:
     bool electricBorderTiling() const {
         return electric_border_tiling;
     }
+    /**
+    * @returns the factor that determines the corner part of the edge (ie. 0.1 means tiny corner)
+    */
+    float electricBorderCornerRatio() const {
+        return electric_border_corner_ratio;
+    }
 
     bool borderlessMaximizedWindows() const {
         return borderless_maximized_windows;
@@ -572,6 +562,9 @@ public:
     bool isGlVSync() const {
         return m_glVSync;
     }
+    bool isColorCorrected() const {
+        return m_colorCorrected;
+    }
     // XRender
     bool isXrenderSmoothScale() const {
         return m_xrenderSmoothScale;
@@ -596,6 +589,9 @@ public:
     bool isGlStrictBindingFollowsDriver() const {
         return m_glStrictBindingFollowsDriver;
     }
+    bool isGlLegacy() const {
+        return m_glLegacy;
+    }
 
     // setters
     void setFocusPolicy(FocusPolicy focusPolicy);
@@ -606,9 +602,6 @@ public:
     void setDelayFocusInterval(int delayFocusInterval);
     void setShadeHover(bool shadeHover);
     void setShadeHoverInterval(int shadeHoverInterval);
-    void setTiling(bool tiling);
-    void setTilingLayout(int tilingLayout);
-    void setTilingRaisePolicy(int tilingRaisePolicy);
     void setSeparateScreenFocus(bool separateScreenFocus);
     void setActiveMouseScreen(bool activeMouseScreen);
     void setPlacement(int placement);
@@ -636,11 +629,13 @@ public:
     void setCommandAll3(MouseCommand commandAll3);
     void setKeyCmdAllModKey(uint keyCmdAllModKey);
     void setShowGeometryTip(bool showGeometryTip);
+    void setCondensedTitle(bool condensedTitle);
     void setElectricBorderDelay(int electricBorderDelay);
     void setElectricBorderCooldown(int electricBorderCooldown);
     void setElectricBorderPushbackPixels(int electricBorderPushbackPixels);
     void setElectricBorderMaximize(bool electricBorderMaximize);
     void setElectricBorderTiling(bool electricBorderTiling);
+    void setElectricBorderCornerRatio(float electricBorderCornerRatio);
     void setBorderlessMaximizedWindows(bool borderlessMaximizedWindows);
     void setKillPingTimeout(int killPingTimeout);
     void setHideUtilityWindowsForInactive(bool hideUtilityWindowsForInactive);
@@ -654,6 +649,7 @@ public:
     void setUnredirectFullscreen(bool unredirectFullscreen);
     void setGlSmoothScale(int glSmoothScale);
     void setGlVSync(bool glVSync);
+    void setColorCorrected(bool colorCorrected);
     void setXrenderSmoothScale(bool xrenderSmoothScale);
     void setMaxFpsInterval(uint maxFpsInterval);
     void setRefreshRate(uint refreshRate);
@@ -661,6 +657,7 @@ public:
     void setGlDirect(bool glDirect);
     void setGlStrictBinding(bool glStrictBinding);
     void setGlStrictBindingFollowsDriver(bool glStrictBindingFollowsDriver);
+    void setGlLegacy(bool glLegacy);
 
     // default values
     static FocusPolicy defaultFocusPolicy() {
@@ -687,15 +684,6 @@ public:
     static int defaultShadeHoverInterval() {
         return 250;
     }
-    static bool defaultTiling() {
-        return false;
-    }
-    static TilingLayoutFactory::Layouts defaultTilingLayout() {
-        return TilingLayoutFactory::DefaultLayout;
-    }
-    static int defaultTilingRaisePolicy() {
-        return 0;
-    }
     static bool defaultSeparateScreenFocus() {
         return false;
     }
@@ -784,6 +772,9 @@ public:
     static bool defaultShowGeometryTip() {
         return false;
     }
+    static bool defaultCondensedTitle() {
+        return false;
+    }
     static ElectricBorderAction defaultElectricBorderTop() {
         return ElectricActionNone;
     }
@@ -826,6 +817,9 @@ public:
     static bool defaultElectricBorderTiling() {
         return true;
     }
+    static float defaultElectricBorderCornerRatio() {
+        return 0.25;
+    }
     static bool defaultBorderlessMaximizedWindows() {
         return false;
     }
@@ -865,6 +859,9 @@ public:
     static bool defaultGlVSync() {
         return true;
     }
+    static bool defaultColorCorrected() {
+        return false;
+    }
     static bool defaultXrenderSmoothScale() {
         return false;
     }
@@ -889,6 +886,9 @@ public:
     static bool defaultGlStrictBindingFollowsDriver() {
         return true;
     }
+    static bool defaultGlLegacy() {
+        return false;
+    }
     static int defaultAnimationSpeed() {
         return 3;
     }
@@ -916,9 +916,6 @@ Q_SIGNALS:
     void delayFocusIntervalChanged();
     void shadeHoverChanged();
     void shadeHoverIntervalChanged();
-    void tilingChanged();
-    void tilingLayoutChanged();
-    void tilingRaisePolicyChanged();
     void separateScreenFocusChanged();
     void activeMouseScreenChanged();
     void placementChanged();
@@ -946,12 +943,14 @@ Q_SIGNALS:
     void commandAll3Changed();
     void keyCmdAllModKeyChanged();
     void showGeometryTipChanged();
+    void condensedTitleChanged();
     void electricBordersChanged();
     void electricBorderDelayChanged();
     void electricBorderCooldownChanged();
     void electricBorderPushbackPixelsChanged();
     void electricBorderMaximizeChanged();
     void electricBorderTilingChanged();
+    void electricBorderCornerRatioChanged();
     void borderlessMaximizedWindowsChanged();
     void killPingTimeoutChanged();
     void hideUtilityWindowsForInactiveChanged();
@@ -965,6 +964,7 @@ Q_SIGNALS:
     void unredirectFullscreenChanged();
     void glSmoothScaleChanged();
     void glVSyncChanged();
+    void colorCorrectedChanged();
     void xrenderSmoothScaleChanged();
     void maxFpsIntervalChanged();
     void refreshRateChanged();
@@ -972,6 +972,7 @@ Q_SIGNALS:
     void glDirectChanged();
     void glStrictBindingChanged();
     void glStrictBindingFollowsDriverChanged();
+    void glLegacyChanged();
 
 private:
     void setElectricBorders(int borders);
@@ -983,9 +984,6 @@ private:
     int m_delayFocusInterval;
     bool m_shadeHover;
     int m_shadeHoverInterval;
-    bool m_tilingOn;
-    TilingLayoutFactory::Layouts m_tilingLayout;
-    int m_tilingRaisePolicy;
     bool m_separateScreenFocus;
     bool m_activeMouseScreen;
     Placement::Policy m_placement;
@@ -1010,6 +1008,7 @@ private:
     bool m_unredirectFullscreen;
     int m_glSmoothScale;
     bool m_glVSync;
+    bool m_colorCorrected;
     bool m_xrenderSmoothScale;
     uint m_maxFpsInterval;
     // Settings that should be auto-detected
@@ -1018,6 +1017,7 @@ private:
     bool m_glDirect;
     bool m_glStrictBinding;
     bool m_glStrictBindingFollowsDriver;
+    bool m_glLegacy;
 
     WindowOperation OpTitlebarDblClick;
 
@@ -1053,8 +1053,10 @@ private:
     int electric_border_pushback_pixels;
     bool electric_border_maximize;
     bool electric_border_tiling;
+    float electric_border_corner_ratio;
     bool borderless_maximized_windows;
     bool show_geometry_tip;
+    bool condensed_title;
     int animationSpeed; // 0 - instant, 5 - very slow
 
     MouseCommand wheelToMouseCommand(MouseWheelCommand com, int delta) const;
