@@ -32,7 +32,6 @@ class Workspace;
 class Deleted;
 class EffectFrameImpl;
 class EffectWindowImpl;
-class LanczosFilter;
 class OverlayWindow;
 class Shadow;
 
@@ -63,8 +62,6 @@ public:
 
     // a new window has been created
     virtual void windowAdded(Toplevel*) = 0;
-    // a window has been destroyed
-    virtual void windowDeleted(Deleted*) = 0;
     /**
      * Method invoked when the screen geometry is changed.
      * Reimplementing classes should also invoke the parent method
@@ -98,11 +95,11 @@ public:
     enum ImageFilterType { ImageFilterFast, ImageFilterGood };
     // there's nothing to paint (adjust time_diff later)
     virtual void idle();
-    bool waitSyncAvailable() {
-        return has_waitSync;
-    }
-    OverlayWindow* overlayWindow();
+    virtual bool waitSyncAvailable() const;
+    virtual OverlayWindow* overlayWindow() = 0;
 public Q_SLOTS:
+    // a window has been destroyed
+    virtual void windowDeleted(KWin::Deleted*) = 0;
     // opacity of a window changed
     virtual void windowOpacityChanged(KWin::Toplevel* c) = 0;
     // shape/size of a window changed
@@ -127,7 +124,7 @@ protected:
     // shared implementation, starts painting the window
     virtual void paintWindow(Window* w, int mask, QRegion region, WindowQuadList quads);
     // called after all effects had their drawWindow() called
-    void finalDrawWindow(EffectWindowImpl* w, int mask, QRegion region, WindowPaintData& data);
+    virtual void finalDrawWindow(EffectWindowImpl* w, int mask, QRegion region, WindowPaintData& data);
     // compute time since the last repaint
     void updateTimeDiff();
     // saved data for 2nd pass of optimized screen painting
@@ -156,9 +153,6 @@ protected:
     int time_diff;
     QElapsedTimer last_time;
     Workspace* wspace;
-    bool has_waitSync;
-    QWeakPointer<LanczosFilter> lanczos_filter;
-    OverlayWindow* m_overlayWindow;
 };
 
 // The base class for windows representations in composite backends
@@ -247,8 +241,6 @@ protected:
     EffectFrameImpl* m_effectFrame;
 };
 
-extern Scene* scene;
-
 inline
 int Scene::Window::x() const
 {
