@@ -550,11 +550,6 @@ void KWin::DeclarativeScript::run()
     pal.setColor(m_view->backgroundRole(), Qt::transparent);
     m_view->setPalette(pal);
 
-
-    foreach (const QString &importPath, KGlobal::dirs()->findDirs("module", "imports")) {
-        m_view->engine()->addImportPath(importPath);
-    }
-
     // add read config
     KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(m_view->engine());
@@ -607,6 +602,12 @@ void KWin::Scripting::start()
 LoadScriptList KWin::Scripting::queryScriptsToLoad()
 {
     KSharedConfig::Ptr _config = KGlobal::config();
+    static bool s_started = false;
+    if (s_started) {
+        _config->reparseConfiguration();
+    } else {
+        s_started = true;
+    }
     QMap<QString,QString> pluginStates = KConfigGroup(_config, "Plugins").entryMap();
     KService::List offers = KServiceTypeTrader::self()->query("KWin/Script");
 
