@@ -33,7 +33,8 @@ namespace KWin
 Toplevel::Toplevel(Workspace* ws)
     : vis(NULL)
     , info(NULL)
-    , ready_for_painting(false)
+    , ready_for_painting(true)
+    , m_isDamaged(false)
     , client(None)
     , frame(None)
     , wspace(ws)
@@ -44,11 +45,9 @@ Toplevel::Toplevel(Workspace* ws)
     , wmClientLeaderWin(0)
     , unredirect(false)
     , unredirectSuspend(false)
+    , m_damageReplyPending(false)
 {
-    m_readyForPaintingTimer = new QTimer(this);
-    m_readyForPaintingTimer->setSingleShot(true);
-    connect(m_readyForPaintingTimer, SIGNAL(timeout()), SLOT(setReadyForPainting()));
-    m_readyForPaintingTimer->start(50);
+    connect(this, SIGNAL(damaged(KWin::Toplevel*,QRect)), SIGNAL(needsRepaint()));
 }
 
 Toplevel::~Toplevel()
@@ -158,26 +157,6 @@ QRect Toplevel::visibleRect() const
     return r.translated(geometry().topLeft());
 }
 
-NET::WindowType Toplevel::windowType(bool direct, int supported_types) const
-{
-    if (supported_types == 0)
-        supported_types = dynamic_cast< const Client* >(this) != NULL
-                          ? SUPPORTED_MANAGED_WINDOW_TYPES_MASK : SUPPORTED_UNMANAGED_WINDOW_TYPES_MASK;
-    NET::WindowType wt = info->windowType(supported_types);
-    if (direct)
-        return wt;
-    const Client* cl = dynamic_cast< const Client* >(this);
-    NET::WindowType wt2 = cl ? cl->rules()->checkType(wt) : wt;
-    if (wt != wt2) {
-        wt = wt2;
-        info->setWindowType(wt);   // force hint change
-    }
-    // hacks here
-    if (wt == NET::Unknown && cl != NULL)   // this is more or less suggested in NETWM spec
-        wt = cl->isTransient() ? NET::Dialog : NET::Normal;
-    return wt;
-}
-
 void Toplevel::getWindowRole()
 {
     window_role = getStringProperty(window(), atoms->wm_window_role).toLower();
@@ -325,8 +304,6 @@ void Toplevel::setOpacity(double new_opacity)
 void Toplevel::setReadyForPainting()
 {
     if (!ready_for_painting) {
-        delete m_readyForPaintingTimer;
-        m_readyForPaintingTimer = 0;
         ready_for_painting = true;
         if (compositing()) {
             addRepaintFull();
