@@ -42,6 +42,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kaction.h>
 #include <kconfiggroup.h>
 #include <kcmdlineargs.h>
+#include <kdeversion.h>
 #include <QtDBus/QtDBus>
 
 #include "client.h"
@@ -81,6 +82,7 @@ namespace KWin
 {
 
 extern int screen_number;
+extern bool is_multihead;
 static const int KWIN_MAX_NUMBER_DESKTOPS = 20;
 
 #ifdef KWIN_BUILD_KAPPMENU
@@ -2171,6 +2173,20 @@ QString Workspace::supportInformation() const
     // all following strings are intended for support. They need to be pasted to e.g forums.kde.org
     // it is expected that the support will happen in English language or that the people providing
     // help understand English. Because of that all texts are not translated
+    support.append("Version\n");
+    support.append("=======\n");
+    support.append("KWin version: ");
+    support.append(KWIN_VERSION_STRING);
+    support.append('\n');
+    support.append("KDE SC version (runtime): ");
+    support.append(KDE::versionString());
+    support.append('\n');
+    support.append("KDE SC version (compile): ");
+    support.append(KDE_VERSION_STRING);
+    support.append('\n');
+    support.append("Qt Version: ");
+    support.append(qVersion());
+    support.append("\n\n");
     support.append("Options\n");
     support.append("=======\n");
     const QMetaObject *metaOptions = options->metaObject();
@@ -2181,6 +2197,25 @@ QString Workspace::supportInformation() const
         }
         support.append(QLatin1String(property.name()) % ": " % options->property(property.name()).toString() % '\n');
     }
+    support.append("\nScreens\n");
+    support.append(  "=======\n");
+    support.append("Multi-Head: ");
+    if (is_multihead) {
+        support.append("yes\n");
+        support.append(QString("Head: %1\n").arg(screen_number));
+    } else {
+        support.append("no\n");
+    }
+    support.append(QString("Number of Screens: %1\n").arg(QApplication::desktop()->screenCount()));
+    for (int i=0; i<QApplication::desktop()->screenCount(); ++i) {
+        const QRect geo = QApplication::desktop()->screenGeometry(i);
+        support.append(QString("Screen %1 Geometry: %2,%3,%4x%5\n")
+                              .arg(i)
+                              .arg(geo.x())
+                              .arg(geo.y())
+                              .arg(geo.width())
+                              .arg(geo.height()));
+    }
     support.append("\nCompositing\n");
     support.append(  "===========\n");
     support.append("Qt Graphics System: ");
