@@ -47,11 +47,19 @@ public:
         CanPause         = 1 << 5,
         CanSeek          = 1 << 6,
         CanGoNext        = 1 << 7,
-        CanGoPrevious    = 1 << 8
+        CanGoPrevious    = 1 << 8,
+        // CanStop is not directly provided by the spec,
+        // but we infer it from PlaybackStatus and CanControl
+        CanStop          = 1 << 9
     };
     Q_DECLARE_FLAGS(Caps, Cap)
     Caps capabilities() const { return m_caps; }
 
+    enum UpdateType {
+        FetchAll,
+        UpdatedSignal
+    };
+
     void refresh();
 
 signals:
@@ -68,8 +76,8 @@ private slots:
     void seeked(qint64 position);
 
 private:
-    void copyProperty(const QString& propName, const QVariant& value, QVariant::Type expType);
-    void updateFromMap(const QVariantMap& map);
+    void copyProperty(const QString& propName, const QVariant& value, QVariant::Type expType, UpdateType updType);
+    void updateFromMap(const QVariantMap& map, UpdateType updType);
     void updatePosition();
     void recalculatePosition();
 
