@@ -55,14 +55,7 @@ XRandrBrightness::XRandrBrightness()
         return;
     }
 
-#ifdef HAS_RANDR_1_3
-    if (minor > 2) {
-        m_resources = XRRGetScreenResourcesCurrent(QX11Info::display(), QX11Info::appRootWindow()); // version 1.3, faster version
-    } else
-#endif
-    {
-        m_resources = XRRGetScreenResources(QX11Info::display(), QX11Info::appRootWindow());
-    }
+    m_resources = XRRGetScreenResources(QX11Info::display(), QX11Info::appRootWindow());
 
     if (!m_resources)
     {
